@@ -2,7 +2,7 @@ from .sequana_config import SequanaConfig
 from .dot_parser import DOTParser
 from .module import Module, modules, pipeline_names
 from .module_finder import ModuleFinder
-from .pipeline_manager import PipelineManager, PipelineManagerGeneric
+from .pipeline_manager import PipelineManager, PipelineManagerGeneric, PipelineManagerDirectory
 from .pipeline_utils import (message, OnSuccessCleaner, OnSuccess, build_dynamic_rule, get_pipeline_statistics,
                              create_cleanup, Makefile)
 from .file_factory import FileFactory, FastQFactory
